@@ -1,10 +1,13 @@
 from pythontools.core import tools
 import os
 
+cfg = None
+
 class Config(object):
 
     def __init__(self, path="", default_config={}):
         self.path = path
+        self.default_config = default_config
         if "%APPDATA%" in self.path:
             self.path = self.path.replace("%APPDATA%", str(os.getenv("APPDATA")))
         if not tools.existDirectory(self.path):
@@ -12,13 +15,26 @@ class Config(object):
                 tools.createDirectory(self.path)
             except:
                 pass
+        self.reloadConfig()
+
+    def reloadConfig(self):
         if not tools.existFile(self.path + "config.json"):
             tools.createFile(self.path + "config.json")
-            tools.saveJson(self.path + "config.json", default_config)
+            tools.saveJson(self.path + "config.json", self.default_config, indent=4)
         self.config = tools.loadJson(self.path + "config.json")
+        global cfg
+        cfg = self
 
     def getConfig(self):
         return self.config
 
     def saveConfig(self):
-        tools.saveJson(self.path + "config.json", self.config)
+        tools.saveJson(self.path + "config.json", self.config, indent=4)
+
+def setConfig(config):
+    global cfg
+    cfg = config
+
+def getConfig():
+    global cfg
+    return cfg
\ No newline at end of file
